@@ -16,7 +16,7 @@ class Agent(object):
         return f"{hash} {v}"
 
     def set(self, id: str, pw: str, k: str, v: Any) -> Any:
-        Broker(app_name=self.__app_name, username=mac(f"{id}:{pw}", self.__hmac_key))\
+        Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))\
             .set(mac(k, self.__hmac_key), self.__encrypt(v))
         return self
 
@@ -27,7 +27,7 @@ class Agent(object):
         raise Exception("credentials are tampered due to different hmac")
 
     def get(self, id: str, pw: str, k: str) -> Any:
-        return self.__decrypt(Broker(app_name=self.__app_name, username=mac(f"{id}:{pw}", self.__hmac_key))
+        return self.__decrypt(Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))
                               .get(mac(k, self.__hmac_key)))
 
 
